@@ -323,6 +323,9 @@ pub struct LogsConfig {
     #[serde(default)]
     success: UiElement,
 
+    #[serde(default)]
+    warning: UiElement,
+
     #[serde(default)]
     error: UiElement,
 }
@@ -331,6 +334,7 @@ impl LogsConfig {
     pub fn extend(mut self, other: Self) -> Self {
         self.info = self.info.extend(other.info);
         self.success = self.success.extend(other.success);
+        self.warning = self.warning.extend(other.warning);
         self.error = self.error.extend(other.error);
         self
     }
@@ -349,6 +353,11 @@ impl LogsConfig {
     pub fn error(&self) -> &UiElement {
         &self.error
     }
+
+    /// Get a reference to the logs config's warning.
+    pub fn warning(&self) -> &UiElement {
+        &self.warning
+    }
 }
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
@@ -636,7 +645,7 @@ impl GeneralConfig {
     }
 }
 
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+#[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct KeyBindings {
     #[serde(default)]
@@ -724,7 +733,7 @@ impl KeyBindings {
     }
 }
 
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+#[derive(Debug, Clone, Default, PartialEq, Serialize, Deserialize)]
 #[serde(deny_unknown_fields)]
 pub struct Mode {
     #[serde(default)]
@@ -839,6 +848,9 @@ pub struct BuiltinModesConfig {
     #[serde(default)]
     default: Mode,
 
+    #[serde(default)]
+    recover: Mode,
+
     #[serde(default)]
     selection_ops: Mode,
 
@@ -888,6 +900,7 @@ pub struct BuiltinModesConfig {
 impl BuiltinModesConfig {
     pub fn extend(mut self, other: Self) -> Self {
         self.default = self.default.extend(other.default);
+        self.recover = self.recover.extend(other.recover);
         self.selection_ops = self.selection_ops.extend(other.selection_ops);
         self.go_to = self.go_to.extend(other.go_to);
         self.create = self.create.extend(other.create);
@@ -913,6 +926,7 @@ impl BuiltinModesConfig {
     pub fn get(&self, name: &str) -> Option<&Mode> {
         match name {
             "default" => Some(&self.default),
+            "recover" => Some(&self.recover),
             "selection ops" => Some(&self.selection_ops),
             "selection_ops" => Some(&self.selection_ops),
             "create" => Some(&self.create),
@@ -1018,6 +1032,11 @@ impl BuiltinModesConfig {
     pub fn switch_layout(&self) -> &Mode {
         &self.switch_layout
     }
+
+    /// Get a reference to the builtin modes config's recover.
+    pub fn recover(&self) -> &Mode {
+        &self.recover
+    }
 }
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
@@ -1236,10 +1255,7 @@ impl Config {
 
     pub fn is_compatible(&self) -> Result<bool> {
         let result = match self.parsed_version()? {
-            (0, 8, 3) => true,
-            (0, 8, 2) => true,
-            (0, 8, 1) => true,
-            (0, 8, 0) => true,
+            (0, 9, 0) => true,
             (_, _, _) => false,
         };
 
@@ -1248,10 +1264,7 @@ impl Config {
 
     pub fn upgrade_notification(&self) -> Result<Option<&str>> {
         let result = match self.parsed_version()? {
-            (0, 8, 3) => None,
-            (0, 8, 2) => None,
-            (0, 8, 1) => None,
-            (0, 8, 0) => Some("App version updated. Fixed breaking UI after rename"),
+            (0, 9, 0) => None,
             (_, _, _) => None,
         };
 
